summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-08-04 21:34:11 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-08-04 21:34:11 (GMT)
commitda9d597e856d8e25317f1a831f0acdcae3b012b5 (patch)
tree39a7694a5f753133e3241465bbccac908c99fd47 /generic
parent449cabad4759a1b39036c3ac365942bb60b6a06a (diff)
downloadtk-da9d597e856d8e25317f1a831f0acdcae3b012b5.zip
tk-da9d597e856d8e25317f1a831f0acdcae3b012b5.tar.gz
tk-da9d597e856d8e25317f1a831f0acdcae3b012b5.tar.bz2
Rename references to CrtSlave -> CrtAlias. Some more slave -> child changes not affecting the API
Diffstat (limited to 'generic')
-rw-r--r--generic/tkConsole.c4
-rw-r--r--generic/tkWindow.c32
2 files changed, 18 insertions, 18 deletions
diff --git a/generic/tkConsole.c b/generic/tkConsole.c
index e8f5920..701ce77 100644
--- a/generic/tkConsole.c
+++ b/generic/tkConsole.c
@@ -816,7 +816,7 @@ InterpreterObjCmd(
if ((otherInterp == NULL) || Tcl_InterpDeleted(otherInterp)) {
Tcl_SetObjResult(interp, Tcl_NewStringObj(
- "no active master interp", -1));
+ "no active parent interp", -1));
Tcl_SetErrorCode(interp, "TK", "CONSOLE", "NO_INTERP", NULL);
return TCL_ERROR;
}
@@ -939,7 +939,7 @@ ConsoleDeleteProc(
*
* ConsoleEventProc --
*
- * This event function is registered on the main window of the slave
+ * This event function is registered on the main window of the child
* interpreter. If the user or a running script causes the main window to
* be destroyed, then we need to inform the console interpreter by
* invoking "::tk::ConsoleExit".
diff --git a/generic/tkWindow.c b/generic/tkWindow.c
index 8ec18e2..a67329c 100644
--- a/generic/tkWindow.c
+++ b/generic/tkWindow.c
@@ -2969,7 +2969,7 @@ Tk_SafeInit(
* Current risks:
*
* - No CPU time limit, no memory allocation limits, no color limits.
* CPU time limits can be imposed by an unsafe master interpreter.
*
* The actual code called is the same as Tk_Init but Tcl_IsSafe() is
* checked at several places to differentiate the two initialisations.
@@ -3081,23 +3081,23 @@ Initialize(
if (Tcl_IsSafe(interp)) {
/*
* Get the clearance to start Tk and the "argv" parameters from the
- * master.
+ * parent.
*/
/*
* Step 1 : find the master and construct the interp name (could be a
* function if new APIs were ok). We could also construct the path
* while walking, but there is no API to get the name of an interp
* either.
*/
- Tcl_Interp *master = interp;
+ Tcl_Interp *parent = interp;
- while (Tcl_IsSafe(master)) {
- master = Tcl_GetMaster(master);
- if (master == NULL) {
+ while (Tcl_IsSafe(parent)) {
+ parent = Tcl_GetMaster(parent);
+ if (parent == NULL) {
Tcl_SetObjResult(interp, Tcl_NewStringObj(
- "no controlling master interpreter", -1));
+ "no controlling parent interpreter", -1));
Tcl_SetErrorCode(interp, "TK", "SAFE", "NO_MASTER", NULL);
return TCL_ERROR;
}
@@ -3107,35 +3107,35 @@ Initialize(
* Construct the name (rewalk...)
*/
- code = Tcl_GetInterpPath(master, interp);
+ code = Tcl_GetInterpPath(parent, interp);
if (code != TCL_OK) {
Tcl_Panic("Tcl_GetInterpPath broken!");
}
/*
* Build the command to eval in trusted master.
*/
cmd = Tcl_NewListObj(2, NULL);
Tcl_ListObjAppendElement(NULL, cmd,
Tcl_NewStringObj("::safe::TkInit", -1));
- Tcl_ListObjAppendElement(NULL, cmd, Tcl_GetObjResult(master));
+ Tcl_ListObjAppendElement(NULL, cmd, Tcl_GetObjResult(parent));
/*
* Step 2 : Eval in the master. The argument is the *reversed* interp
* path of the slave.
*/
Tcl_IncrRefCount(cmd);
- code = Tcl_EvalObjEx(master, cmd, 0);
+ code = Tcl_EvalObjEx(parent, cmd, 0);
Tcl_DecrRefCount(cmd);
- Tcl_TransferResult(master, code, interp);
+ Tcl_TransferResult(parent, code, interp);
if (code != TCL_OK) {
return code;
}
/*
* Use the master's result as argv. Note: We don't use the Obj
* interfaces to avoid dealing with cross interp refcounting and
* changing the code below.
*/
@@ -2969,7 +2969,7 @@ Tk_SafeInit(
*
* - No CPU time limit, no memory allocation limits, no color limits.
- * CPU time limits can be imposed by an unsafe master interpreter.
+ * CPU time limits can be imposed by an unsafe parent interpreter.
*
* The actual code called is the same as Tk_Init but Tcl_IsSafe() is
@@ -3081,23 +3081,23 @@ Initialize(
*/
/*
- * Step 1 : find the master and construct the interp name (could be a
+ * Step 1 : find the parent and construct the interp name (could be a
* function if new APIs were ok). We could also construct the path
* while walking, but there is no API to get the name of an interp
@@ -3107,35 +3107,35 @@ Initialize(
}
/*
- * Build the command to eval in trusted master.
+ * Build the command to eval in trusted parent.
*/
cmd = Tcl_NewListObj(2, NULL);
@@ -3107,35 +3107,35 @@ Initialize(
/*
- * Step 2 : Eval in the master. The argument is the *reversed* interp
- * path of the slave.
+ * Step 2 : Eval in the parent. The argument is the *reversed* interp
+ * path of the child.
*/
Tcl_IncrRefCount(cmd);
@@ -3107,35 +3107,35 @@ Initialize(
}
/*
- * Use the master's result as argv. Note: We don't use the Obj
+ * Use the parent's result as argv. Note: We don't use the Obj
* interfaces to avoid dealing with cross interp refcounting and
* changing the code below.